@@ -76,6 +76,9 @@ gpg -u 8B81C9D17413A06D --output "$RELEASE_DIR"/install.sh.sig --sign "$RELEASE_
 minisign -WSs "$BASE_DIR/minisign.key" -p "$BASE_DIR/minisign.pub" -m "$RELEASE_DIR"/install.sh </dev/zero
 cp "$RELEASE_DIR"/{install.sh,install.sh.sig,install.sh.minisig} "$RELEASE_DIR/$MISE_VERSION"
 
+echo "::group::mise.run scripts"
+./scripts/render-mise-run.sh
+
 echo "::group::Sign source tarball"
 TMP_FILE="$(mktemp)"
 curl -L -o "$TMP_FILE" "https://github.com/jdx/mise/archive/refs/tags/$MISE_VERSION.tar.gz"
@@ -88,7 +91,10 @@ if [[ $DRY_RUN != 1 ]]; then
 	#  echo "::group::Publish npm mise-cli"
 	#  NPM_PREFIX=mise-cli ./scripts/release-npm.sh
 	echo "::group::Publish r2"
-	./scripts/publish-r2.sh
+	# TODO: remove || true when working
+	./scripts/publish-r2.sh || true
+	echo "::group::Deploy Cloudflare Worker"
+	./scripts/deploy-worker.sh
 	echo "::group::Publish GitHub releases as draft"
 	gh release edit --draft=true "$MISE_VERSION"
 fi
