@@ -54,6 +54,11 @@ impl Backend for HttpBackend {
         let filename = get_filename_from_url(&url);
         let file_path = tv.download_path().join(&filename);
 
+        // Store the asset URL in the tool version
+        let platform_key = self.get_platform_key();
+        let platform_info = tv.lock_platforms.entry(platform_key).or_default();
+        platform_info.url = Some(url.clone());
+
         ctx.pr.set_message(format!("download {filename}"));
         HTTP.download_file(&url, &file_path, Some(&ctx.pr)).await?;
 
