@@ -80,8 +80,6 @@ impl Backend for NPMBackend {
             CmdLineRunner::new("bun")
                 .arg("install")
                 .arg(format!("{}@{}", self.tool_name(), tv.version))
-                .arg("--cwd")
-                .arg(tv.install_path())
                 .arg("--global")
                 .arg("--trust")
                 .with_pr(&ctx.pr)
@@ -95,6 +93,7 @@ impl Backend for NPMBackend {
                         .list_paths(&ctx.config)
                         .await,
                 )?
+                .current_dir(tv.install_path())
                 .execute()?;
         } else {
             CmdLineRunner::new(NPM_PROGRAM)
